@@ -1,4 +1,5 @@
 """A10 support."""
+from __future__ import unicode_literals
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
 
@@ -6,6 +7,7 @@ class A10SSH(CiscoSSHConnection):
     """A10 support."""
     def session_preparation(self):
         """A10 requires to be enable mode to disable paging."""
+        self._test_channel_read()
         self.set_base_prompt()
         self.enable()
         self.disable_paging(command="terminal length 0\n")
