@@ -1,4 +1,7 @@
 """Aruba OS support"""
+from __future__ import unicode_literals
+import time
+import re
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
 
@@ -6,6 +9,9 @@ class ArubaSSH(CiscoSSHConnection):
     """Aruba OS support"""
     def session_preparation(self):
         """Aruba OS requires enable mode to disable paging."""
+        delay_factor = self.select_delay_factor(delay_factor=0)
+        time.sleep(1 * delay_factor)
+        self._test_channel_read()
         self.set_base_prompt()
         self.enable()
         self.disable_paging(command="no paging")
@@ -17,6 +23,6 @@ class ArubaSSH(CiscoSSHConnection):
         Aruba uses "(<controller name>) (config) #" as config prompt
         """
         if not pattern:
-            pattern = self.base_prompt[:16]
+            pattern = re.escape(self.base_prompt[:16])
         return super(ArubaSSH, self).check_config_mode(check_string=check_string,
                                                        pattern=pattern)
