@@ -1,9 +1,11 @@
-from netmiko.cisco.cisco_ios import CiscoIosSSH, CiscoIosTelnet
+from __future__ import unicode_literals
+from netmiko.cisco.cisco_ios import CiscoIosBase, CiscoIosSSH, CiscoIosTelnet
 from netmiko.cisco.cisco_asa_ssh import CiscoAsaSSH
 from netmiko.cisco.cisco_nxos_ssh import CiscoNxosSSH
 from netmiko.cisco.cisco_xr_ssh import CiscoXrSSH
 from netmiko.cisco.cisco_wlc_ssh import CiscoWlcSSH
 from netmiko.cisco.cisco_s300 import CiscoS300SSH
+from netmiko.cisco.cisco_tp_tcce import CiscoTpTcCeSSH
 
 __all__ = ['CiscoIosSSH', 'CiscoIosTelnet', 'CiscoAsaSSH', 'CiscoNxosSSH', 'CiscoXrSSH',
-           'CiscoWlcSSH', 'CiscoS300SSH']
+           'CiscoWlcSSH', 'CiscoS300SSH', 'CiscoTpTcCeSSH', 'CiscoIosBase']
