@@ -1,19 +1,15 @@
 from __future__ import print_function
 from __future__ import unicode_literals
 import re
-import time
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
 
 class CiscoNxosSSH(CiscoSSHConnection):
-    def session_preparation(self):
-        """
-        Prepare the session after the connection has been established.
 
-        Nexus 5020 required extra delay post login
-        """
-        time.sleep(2)
-        self.clear_buffer()
+    def session_preparation(self):
+        """Prepare the session after the connection has been established."""
+        self._test_channel_read(pattern=r'[>#]')
+        self.ansi_escape_codes = True
         self.set_base_prompt()
         self.disable_paging()
 
