@@ -2,8 +2,11 @@
 from __future__ import print_function
 from __future__ import unicode_literals
 import time
+import re
 
 from netmiko.base_connection import BaseConnection
+from netmiko.py23_compat import string_types
+from netmiko import log
 
 
 class CiscoWlcSSH(BaseConnection):
@@ -97,6 +100,7 @@ class CiscoWlcSSH(BaseConnection):
 
         Cisco WLC uses "config paging disable" to disable paging
         '''
+        self._test_channel_read()
         self.set_base_prompt()
         self.disable_paging(command="config paging disable\n")
 
@@ -107,19 +111,19 @@ class CiscoWlcSSH(BaseConnection):
     def check_config_mode(self, check_string='config', pattern=''):
         """Checks if the device is in configuration mode or not."""
         if not pattern:
-            pattern = self.base_prompt
+            pattern = re.escape(self.base_prompt)
         return super(CiscoWlcSSH, self).check_config_mode(check_string, pattern)
 
     def config_mode(self, config_command='config', pattern=''):
         """Enter into config_mode."""
         if not pattern:
-            pattern = self.base_prompt
+            pattern = re.escape(self.base_prompt)
         return super(CiscoWlcSSH, self).config_mode(config_command, pattern)
 
     def exit_config_mode(self, exit_config='exit', pattern=''):
         """Exit config_mode."""
         if not pattern:
-            pattern = self.base_prompt
+            pattern = re.escape(self.base_prompt)
         return super(CiscoWlcSSH, self).exit_config_mode(exit_config, pattern)
 
     def send_config_set(self, config_commands=None, exit_config_mode=True, delay_factor=1,
@@ -132,10 +136,12 @@ class CiscoWlcSSH(BaseConnection):
 
         Does not automatically exit/enter configuration mode.
         """
-        debug = False
         delay_factor = self.select_delay_factor(delay_factor)
         if config_commands is None:
             return ''
+        elif isinstance(config_commands, string_types):
+            config_commands = (config_commands,)
+
         if not hasattr(config_commands, '__iter__'):
             raise ValueError("Invalid argument passed into send_config_set")
 
@@ -147,6 +153,5 @@ class CiscoWlcSSH(BaseConnection):
         # Gather output
         output = self._read_channel_timing(delay_factor=delay_factor, max_loops=max_loops)
         output = self._sanitize_output(output)
-        if debug:
-            print(output)
+        log.debug("{0}".format(output))
         return output
