@@ -1,4 +1,5 @@
 """Enterasys support."""
+from __future__ import unicode_literals
 from netmiko.cisco_base_connection import CiscoSSHConnection
 
 
@@ -6,6 +7,6 @@ class EnterasysSSH(CiscoSSHConnection):
     """Enterasys support."""
     def session_preparation(self):
         """Enterasys requires enable mode to disable paging."""
-        self.enable()
+        self._test_channel_read()
         self.set_base_prompt()
         self.disable_paging(command="set length 0\n")
