@@ -1,13 +1,16 @@
 from __future__ import print_function
 from __future__ import unicode_literals
 import time
+import re
 from netmiko.cisco_base_connection import CiscoSSHConnection
+from netmiko import log
 
 
 class HuaweiSSH(CiscoSSHConnection):
 
     def session_preparation(self):
         """Prepare the session after the connection has been established."""
+        self._test_channel_read()
         self.set_base_prompt()
         self.disable_paging(command="screen-length 0 temporary\n")
 
@@ -23,9 +26,21 @@ class HuaweiSSH(CiscoSSHConnection):
         """Checks whether in configuration mode. Returns a boolean."""
         return super(HuaweiSSH, self).check_config_mode(check_string=check_string)
 
+    def check_enable_mode(self, *args, **kwargs):
+        """Huawei has no enable mode."""
+        pass
+
+    def enable(self, *args, **kwargs):
+        """Huawei has no enable mode."""
+        return ''
+
+    def exit_enable_mode(self, *args, **kwargs):
+        """Huawei has no enable mode."""
+        return ''
+
     def set_base_prompt(self, pri_prompt_terminator='>', alt_prompt_terminator=']',
                         delay_factor=1):
-        '''
+        """
         Sets self.base_prompt
 
         Used as delimiter for stripping of trailing prompt in output.
@@ -34,11 +49,8 @@ class HuaweiSSH(CiscoSSHConnection):
         this will be the router prompt with < > or [ ] stripped off.
 
         This will be set on logging in, but not when entering system-view
-        '''
-        debug = False
-        if debug:
-            print("In set_base_prompt")
-
+        """
+        log.debug("In set_base_prompt")
         delay_factor = self.select_delay_factor(delay_factor)
         self.clear_buffer()
         self.write_channel("\n")
@@ -55,13 +67,13 @@ class HuaweiSSH(CiscoSSHConnection):
         if not prompt[-1] in (pri_prompt_terminator, alt_prompt_terminator):
             raise ValueError("Router prompt not found: {0}".format(prompt))
 
+        # Strip off any leading HRP_. characters for USGv5 HA
+        prompt = re.sub(r"^HRP_.", "", prompt, flags=re.M)
+
         # Strip off leading and trailing terminator
         prompt = prompt[1:-1]
         prompt = prompt.strip()
-
         self.base_prompt = prompt
-
-        if debug:
-            print("prompt: {}".format(self.base_prompt))
+        log.debug("prompt: {0}".format(self.base_prompt))
 
         return self.base_prompt
