@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 import re
 import socket
 import time
@@ -62,7 +64,6 @@ class LinuxSSH(CiscoSSHConnection):
         if not self.check_enable_mode():
             self.write_channel(self.normalize_cmd(cmd))
             time.sleep(.3 * delay_factor)
-            pattern = re.escape(pattern)
             try:
                 output += self.read_channel()
                 if re.search(pattern, output, flags=re_flags):
@@ -71,5 +72,7 @@ class LinuxSSH(CiscoSSHConnection):
             except socket.timeout:
                 raise NetMikoTimeoutException("Timed-out reading channel, data not available.")
             if not self.check_enable_mode():
-                raise ValueError("Failed to enter enable mode.")
+                msg = "Failed to enter enable mode. Please ensure you pass " \
+                      "the 'secret' argument to ConnectHandler."
+                raise ValueError(msg)
         return output
