@@ -11,9 +11,11 @@ SHOW_RUN_MAPPER = {
     'juniper': 'show configuration',
     'juniper_junos': 'show configuration',
     'extreme': 'show configuration',
+    'extreme_wing': 'show running-config',
     'hp_comware': 'display current-configuration',
     'huawei': 'display current-configuration',
     'fortinet': 'show full-configuration',
+    'checkpoint': 'show configuration',
     'cisco_wlc': 'show run-config',
     'enterasys': 'show running-config',
     'dell_force10': 'show running-config',
@@ -23,6 +25,7 @@ SHOW_RUN_MAPPER = {
     'brocade_nos': 'show running-config',
     'brocade_fastiron': 'show running-config',
     'brocade_netiron': 'show running-config',
+    'alcatel_aos': 'show configuration snapshot',
 }
 
 # Expand SHOW_RUN_MAPPER to include '_ssh' key
@@ -44,15 +47,15 @@ def load_yaml_file(yaml_file):
     except ImportError:
         sys.exit("Unable to import yaml module.")
     try:
-        with io.open(yaml_file, encoding='utf-8') as fname:
+        with io.open(yaml_file, "rt", encoding='utf-8') as fname:
             return yaml.load(fname)
     except IOError:
         sys.exit("Unable to open YAML file: {0}".format(yaml_file))
 
 
-def load_devices():
+def load_devices(file_name=None):
     """Find and load .netmiko.yml file."""
-    yaml_devices_file = find_cfg_file()
+    yaml_devices_file = find_cfg_file(file_name)
     return load_yaml_file(yaml_devices_file)
 
 
